import os
import jwt
from fastapi import HTTPException, Security
from fastapi.security import HTTPAuthorizationCredentials, HTTPBearer


class JWT():
    security = HTTPBearer()
    secret = os.getenv('SECRET_JWT_TESTE')

    def decode_token(self, token):
        try:
            payload = jwt.decode(token, self.secret, algorithms=["HS256"])
            return payload["user"]

        except jwt.ExpiredSignatureError as e:
            raise HTTPException(status_code=401, detail="Token Expirado") from e
        except jwt.InvalidTokenError as e:
            raise HTTPException(status_code=401, detail="Token Invalido") from e

    def auth_wrapper(
        self,
        auth: HTTPAuthorizationCredentials = Security(security)
    ):
        return self.decode_token(auth.credentials)



from setuptools import setup

with open("README.md", "r") as fh:
    readme = fh.read()

setup(
    name='qflash_jwt_package',
    version='0.0.1',
    url='https://github.com/Quasar-Flash',
    license='MIT License',
    author='Marlon Martins',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='marlon.martins@qflash.com.br',
    keywords='Package',
    description=u'a small package for implement jwt security in API',
    packages=['qflash_jwt_package'],
    install_requires=['fastapi', 'pyjwt==1.7.1'],
)